@@ -120,16 +120,11 @@ class GenericExample
   end
 
   Contract C::KeywordArgs[:name => String, :age => Fixnum] => nil
-  def person_keywordargs(data)
-  end
-
-  # Testing overloaded method
-  Contract String, Fixnum => nil
-  def person_keywordargs(name, age)
+  def person_keywordargs(name: "name", age: 10)
   end
 
   Contract C::KeywordArgs[:hash => C::HashOf[Symbol, C::Num]] => nil
-  def hash_keywordargs(data)
+  def hash_keywordargs(hash:)
   end
 
   Contract (/foo/) => nil
@@ -152,6 +147,30 @@ class GenericExample
   def nested_array_complex_contracts(data)
   end
 
+  Contract [
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol]
+  ] => nil
+  def long_array_param_contracts(data)
+  end
+
+  Contract C::None => [
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol],
+    C::Or[String, Symbol]
+  ]
+  def long_array_return_contracts
+  end
+
   Contract Proc => C::Any
   def do_call(&block)
     block.call
